"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
var _react = _interopRequireDefault(require("react"));
var _reactNative = require("react-native");
var _utils = require("./utils");
var _regexes = require("./regexes");
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
const HighlightedText = _ref => {
  let {
    children,
    highlights,
    caseSensitive,
    hashtags,
    hashtagStyle = {
      color: 'blue'
    },
    onHashtagPress = () => {},
    mentions,
    mentionStyle = {
      color: 'blue'
    },
    onMentionPress = () => {},
    emails,
    emailStyle = {
      color: 'blue'
    },
    onEmailPress = () => {},
    links,
    linkStyle = {
      color: 'blue'
    },
    onLinkPress = () => {},
    ...props
  } = _ref;
  let text = '';
  _react.default.Children.map(children, child => {
    if (typeof child === 'string') {
      text += child;
    }
  });
  const chunks = (0, _utils.splitText)({
    text,
    highlights,
    caseSensitive,
    hashtags,
    mentions,
    emails,
    links
  });
  return /*#__PURE__*/_react.default.createElement(_reactNative.Text, props, chunks.map((chunk, index) => {
    let keyword = null;
    if (highlights) {
      highlights.map(item => {
        const itemRegex = new RegExp(`^${item.regexSource.join('|')}$`, caseSensitive ? 'gm' : 'gmi');
        if (itemRegex.test(chunk)) {
          keyword = /*#__PURE__*/_react.default.createElement(_reactNative.TouchableWithoutFeedback, {
            key: index,
            onPress: () => item.onPress(chunk)
          }, /*#__PURE__*/_react.default.createElement(_reactNative.Text, {
            style: item.style
          }, chunk));
        }
      });
    }
    if (_regexes.hashtagRegexTester.test(chunk)) {
      return /*#__PURE__*/_react.default.createElement(_reactNative.TouchableWithoutFeedback, {
        key: index,
        onPress: () => onHashtagPress(chunk)
      }, /*#__PURE__*/_react.default.createElement(_reactNative.Text, {
        style: hashtagStyle
      }, chunk));
    }
    if (_regexes.mentionRegexTester.test(chunk)) {
      return /*#__PURE__*/_react.default.createElement(_reactNative.TouchableWithoutFeedback, {
        key: index,
        onPress: () => onMentionPress(chunk)
      }, /*#__PURE__*/_react.default.createElement(_reactNative.Text, {
        style: mentionStyle
      }, chunk));
    }
    if (_regexes.emailRegexTester.test(chunk)) {
      return /*#__PURE__*/_react.default.createElement(_reactNative.TouchableWithoutFeedback, {
        key: index,
        onPress: () => onEmailPress(chunk)
      }, /*#__PURE__*/_react.default.createElement(_reactNative.Text, {
        style: emailStyle
      }, chunk));
    }
    if (_regexes.urlRegexTester.test(chunk)) {
      return /*#__PURE__*/_react.default.createElement(_reactNative.TouchableWithoutFeedback, {
        key: index,
        onPress: () => onLinkPress(chunk)
      }, /*#__PURE__*/_react.default.createElement(_reactNative.Text, {
        style: linkStyle
      }, chunk));
    }
    if (keyword) {
      return keyword;
    }
    return /*#__PURE__*/_react.default.createElement(_reactNative.Text, {
      key: index
    }, chunk);
  }));
};
var _default = HighlightedText;
exports.default = _default;
//# sourceMappingURL=HighlightedText.js.map