"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.splitText = exports.formatedHtml = void 0;
var _regexes = require("./regexes");
const splitText = _ref => {
  let {
    text,
    highlights,
    caseSensitive,
    hashtags,
    mentions,
    emails,
    links
  } = _ref;
  const highlightRegex = [];
  highlights && highlights.forEach(item => {
    highlightRegex.push(...item.regexSource);
  });
  hashtags && highlightRegex.push(`(${_regexes.hashtagRegex.source})`);
  mentions && highlightRegex.push(`(${_regexes.mentionRegex.source})`);
  emails && highlightRegex.push(`(${_regexes.emailRegex.source})`);
  links && highlightRegex.push(`(${_regexes.urlRegex.source})`);
  const finalRegex = new RegExp(highlightRegex.join('|'), caseSensitive ? 'gm' : 'gmi');
  const parts = text ? text.split(finalRegex).filter(i => i !== undefined && i !== '') : [];
  return parts;
};
exports.splitText = splitText;
const formatedHtml = _ref2 => {
  let {
    text,
    highlights,
    caseSensitive,
    hashtags,
    hashtagClassName,
    hashtagUrl,
    mentions,
    mentionClassName,
    mentionUrl,
    emails,
    emailClassName,
    emailUrl,
    links,
    linkClassName
  } = _ref2;
  const chunks = splitText({
    text,
    highlights,
    caseSensitive,
    hashtags,
    mentions,
    emails,
    links
  });
  let html = '';
  chunks.map(chunk => {
    let keyword = null;
    if (highlights) {
      highlights.map(item => {
        const itemRegex = new RegExp(`^${item.regexSource.join('|')}$`, caseSensitive ? 'gm' : 'gmi');
        if (itemRegex.test(chunk)) {
          keyword = `<span class=${item.className}>${chunk}</span>`;
        }
      });
    }
    if (keyword) {
      html += keyword;
    } else if (_regexes.hashtagRegexTester.test(chunk)) {
      html += hashtagUrl ? `<a class=${hashtagClassName || ''} href=${hashtagUrl(chunk)}>${chunk}</a>` : `<span class=${hashtagClassName || ''}>${chunk}</span>`;
    } else if (_regexes.mentionRegexTester.test(chunk)) {
      html += mentionUrl ? `<a class=${mentionClassName || ''} href=${mentionUrl(chunk)}>${chunk}</a>` : `<span class=${mentionClassName || ''}>${chunk}</span>`;
    } else if (_regexes.emailRegexTester.test(chunk)) {
      html += emailUrl ? `<a class=${emailClassName || ''} href=${emailUrl(chunk)}>${chunk}</a>` : `<span class=${emailClassName || ''}>${chunk}</span>`;
    } else if (_regexes.urlRegexTester.test(chunk)) {
      html += `<a class=${linkClassName || ''} href=${chunk}>${chunk}</a>`;
    } else html += `<span>${chunk}</span>`;
  });
  return html;
};
exports.formatedHtml = formatedHtml;
//# sourceMappingURL=utils.js.map