import React from 'react';
import { Text, TouchableWithoutFeedback } from 'react-native';
import { splitText } from './utils';
import { mentionRegexTester, hashtagRegexTester, emailRegexTester, urlRegexTester } from './regexes';
const HighlightedText = _ref => {
  let {
    children,
    highlights,
    caseSensitive,
    hashtags,
    hashtagStyle = {
      color: 'blue'
    },
    onHashtagPress = () => {},
    mentions,
    mentionStyle = {
      color: 'blue'
    },
    onMentionPress = () => {},
    emails,
    emailStyle = {
      color: 'blue'
    },
    onEmailPress = () => {},
    links,
    linkStyle = {
      color: 'blue'
    },
    onLinkPress = () => {},
    ...props
  } = _ref;
  let text = '';
  React.Children.map(children, child => {
    if (typeof child === 'string') {
      text += child;
    }
  });
  const chunks = splitText({
    text,
    highlights,
    caseSensitive,
    hashtags,
    mentions,
    emails,
    links
  });
  return /*#__PURE__*/React.createElement(Text, props, chunks.map((chunk, index) => {
    let keyword = null;
    if (highlights) {
      highlights.map(item => {
        const itemRegex = new RegExp(`^${item.regexSource.join('|')}$`, caseSensitive ? 'gm' : 'gmi');
        if (itemRegex.test(chunk)) {
          keyword = /*#__PURE__*/React.createElement(TouchableWithoutFeedback, {
            key: index,
            onPress: () => item.onPress(chunk)
          }, /*#__PURE__*/React.createElement(Text, {
            style: item.style
          }, chunk));
        }
      });
    }
    if (hashtagRegexTester.test(chunk)) {
      return /*#__PURE__*/React.createElement(TouchableWithoutFeedback, {
        key: index,
        onPress: () => onHashtagPress(chunk)
      }, /*#__PURE__*/React.createElement(Text, {
        style: hashtagStyle
      }, chunk));
    }
    if (mentionRegexTester.test(chunk)) {
      return /*#__PURE__*/React.createElement(TouchableWithoutFeedback, {
        key: index,
        onPress: () => onMentionPress(chunk)
      }, /*#__PURE__*/React.createElement(Text, {
        style: mentionStyle
      }, chunk));
    }
    if (emailRegexTester.test(chunk)) {
      return /*#__PURE__*/React.createElement(TouchableWithoutFeedback, {
        key: index,
        onPress: () => onEmailPress(chunk)
      }, /*#__PURE__*/React.createElement(Text, {
        style: emailStyle
      }, chunk));
    }
    if (urlRegexTester.test(chunk)) {
      return /*#__PURE__*/React.createElement(TouchableWithoutFeedback, {
        key: index,
        onPress: () => onLinkPress(chunk)
      }, /*#__PURE__*/React.createElement(Text, {
        style: linkStyle
      }, chunk));
    }
    if (keyword) {
      return keyword;
    }
    return /*#__PURE__*/React.createElement(Text, {
      key: index
    }, chunk);
  }));
};
export default HighlightedText;
//# sourceMappingURL=HighlightedText.js.map